pub struct StdinMultiplexer { /* private fields */ }Expand description
A shared stdin reader that can be monitored by a background thread to intercept control characters (like Ctrl-C) on platforms without signals.
Implementations
Sourceimpl StdinMultiplexer
impl StdinMultiplexer
pub fn new(cancel_token: CancellationToken) -> Arc<Self> ⓘ
pub fn subscribe(&self) -> MultiplexedReader ⓘ