Structs
- ArcVec
Writer - A thread-safe writer backed by a shared
Vec<u8>. Useful for tests. - Command
Registry - Registry of named commands.
- InMemory
History - IoContext
- Context for utility IO, allowing redirection of stdin, stdout, and stderr.
- Line
Buffer - A stateful editor for a single line of text buffer.
- Line
Editor - A minimal line editor with command history.
- Multiplexed
Reader - Stdin
Multiplexer - A shared stdin reader that can be monitored by a background thread to intercept control characters (like Ctrl-C) on platforms without signals.
Enums
- KeyEvent
- Loop
Action - Controls the REPL loop flow after a line is handled.
Traits
- History
- KeyEvent
Handler - Line
Handler - Trait for handling lines read by [
LineReader].
Functions
- handle_
command_ line - Execute a complete command line, splitting by
&&and running sequentially. Stops execution if any command in the sequence fails. - handle_
parallel - Execute multiple independent command lines in parallel.
- handle_
pipeline - Execute a shell pipeline (commands separated by
|).
Type Aliases
- Command
Fn - A function that handles a shell command.